@@ -13,7 +13,7 @@ pub struct TableForeignKey {
 }
 
 /// Foreign key on update & on delete actions
-#[derive(Debug, Clone)]
+#[derive(Debug, Clone, Copy)]
 pub enum ForeignKeyAction {
     Restrict,
     Cascade,
@@ -111,6 +111,14 @@ impl TableForeignKey {
             .collect()
     }
 
+    pub fn get_on_delete(&self) -> Option<ForeignKeyAction> {
+        self.on_delete
+    }
+
+    pub fn get_on_update(&self) -> Option<ForeignKeyAction> {
+        self.on_update
+    }
+
     pub fn take(&mut self) -> Self {
         Self {
             name: self.name.take(),
