@@ -9,6 +9,7 @@ pub enum ConditionType {
 /// Represents the value of an [`Condition::any`] or [`Condition::all`]: a set of disjunctive or conjunctive conditions.
 #[derive(Debug, Clone)]
 pub struct Condition {
+    pub(crate) negate: bool,
     pub(crate) condition_type: ConditionType,
     pub(crate) conditions: Vec<ConditionExpression>,
 }
@@ -45,6 +46,24 @@ impl Condition {
     ///
     /// If it's an [`Condition::any`], it will be separated from the others by an `" OR "` in the query. If it's
     /// an [`Condition::all`], it will be separated by an `" AND "`.
+    ///
+    /// ```
+    /// use sea_query::{tests_cfg::*, *};
+    ///
+    /// let statement = sea_query::Query::select()
+    ///     .column(Glyph::Id)
+    ///     .from(Glyph::Table)
+    ///     .cond_where(
+    ///         Cond::all()
+    ///             .add(Expr::col(Glyph::Aspect).eq(0).into_condition().not())
+    ///             .add(Expr::col(Glyph::Id).eq(0).into_condition().not()),
+    ///     )
+    ///     .to_string(PostgresQueryBuilder);
+    /// assert_eq!(
+    ///     statement,
+    ///     r#"SELECT "id" FROM "glyph" WHERE (NOT ("aspect" = 0)) AND (NOT ("id" = 0))"#
+    /// );
+    /// ```
     #[allow(clippy::should_implement_trait)]
     pub fn add<C>(mut self, condition: C) -> Self
     where
@@ -57,7 +76,7 @@ impl Condition {
                 return self;
             }
             // Skip the junction if there is only one.
-            if c.conditions.len() == 1 {
+            if c.conditions.len() == 1 && !c.negate {
                 expr = c.conditions.pop().unwrap();
             }
         }
@@ -68,6 +87,27 @@ impl Condition {
     /// Add an optional condition to the set.
     ///
     /// Shorthand for `if o.is_some() { self.add(o) }`
+    ///
+    /// # Examples
+    ///
+    /// ```
+    /// use sea_query::{*, tests_cfg::*};
+    ///
+    /// let query = Query::select()
+    ///     .column(Glyph::Image)
+    ///     .from(Glyph::Table)
+    ///     .cond_where(
+    ///         Cond::all()
+    ///             .add_option(Some(Expr::tbl(Glyph::Table, Glyph::Image).like("A%")))
+    ///             .add_option(None::<SimpleExpr>)
+    ///     )
+    ///     .to_owned();
+    ///
+    /// assert_eq!(
+    ///     query.to_string(MysqlQueryBuilder),
+    ///     r#"SELECT `image` FROM `glyph` WHERE `glyph`.`image` LIKE 'A%'"#
+    /// );
+    /// ```
     #[allow(clippy::should_implement_trait)]
     pub fn add_option<C>(self, other: Option<C>) -> Self
     where
@@ -104,6 +144,7 @@ impl Condition {
     /// ```
     pub fn any() -> Condition {
         Condition {
+            negate: false,
             condition_type: ConditionType::Any,
             conditions: Vec::new(),
         }
@@ -133,10 +174,69 @@ impl Condition {
     /// ```
     pub fn all() -> Condition {
         Condition {
+            negate: false,
             condition_type: ConditionType::All,
             conditions: Vec::new(),
         }
     }
+
+    /// Negates a condition.
+    ///
+    /// # Examples
+    ///
+    /// ```
+    /// use sea_query::{*, tests_cfg::*};
+    ///
+    /// let query = Query::select()
+    ///     .column(Glyph::Image)
+    ///     .from(Glyph::Table)
+    ///     .cond_where(
+    ///         Cond::all()
+    ///             .not()
+    ///             .add(Expr::tbl(Glyph::Table, Glyph::Aspect).is_in(vec![3, 4]))
+    ///             .add(Expr::tbl(Glyph::Table, Glyph::Image).like("A%"))
+    ///     )
+    ///     .to_owned();
+    ///
+    /// assert_eq!(
+    ///     query.to_string(MysqlQueryBuilder),
+    ///     r#"SELECT `image` FROM `glyph` WHERE NOT (`glyph`.`aspect` IN (3, 4) AND `glyph`.`image` LIKE 'A%')"#
+    /// );
+    /// ```
+    ///
+    /// # More Examples
+    ///
+    /// ```
+    /// use sea_query::{*, tests_cfg::*};
+    ///
+    /// let query = Query::select()
+    ///     .column(Glyph::Id)
+    ///     .cond_where(
+    ///         Cond::all()
+    ///             .add(
+    ///                 Cond::all()
+    ///                     .not()
+    ///                     .add(Expr::val(1).eq(1))
+    ///                     .add(Expr::val(2).eq(2))
+    ///             )
+    ///             .add(
+    ///                 Cond::any()
+    ///                     .add(Expr::val(3).eq(3))
+    ///                     .add(Expr::val(4).eq(4))
+    ///             )
+    ///     )
+    ///     .to_owned();
+    ///
+    /// assert_eq!(
+    ///     query.to_string(MysqlQueryBuilder),
+    ///     r#"SELECT `id` WHERE (NOT (1 = 1 AND 2 = 2)) AND (3 = 3 OR 4 = 4)"#
+    /// );
+    /// ```
+    #[allow(clippy::should_implement_trait)]
+    pub fn not(mut self) -> Self {
+        self.negate = !self.negate;
+        self
+    }
 }
 
 impl std::convert::From<Condition> for ConditionExpression {
